#!/usr/bin/python
import web
from hashlib import sha256

db = web.database(dbn='sqlite', db='/var/www/gasmilage/milage.db')
urls = (
	'/', 'index',
	'/add', 'add',
	'/change', 'change'
)
render = web.template.render('/var/www/gasmilage/templates/')

def calcLPerKM(liters, kilometers):
	return round(liters / (kilometers/100), 2)

def calcMPG(liters, kilometers):
	return round((235.2146 / (liters / (kilometers/100))), 2)

def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        return False

def checkPass(enteredPass):
	# The default password for /change is: P@ssw0rd
	# Replace it as soon as possible. Generating a new one from a python shell is easy. 
	# from hashlib import sha256
	# sha256("Your New Password Here").hexdigest()
	password = 'b03ddf3ca2e714a6548e7495e2a03f5e824eaac9837cd7f159c67b90fb4b7342'
	if sha256(enteredPass).hexdigest() == password:
		return True
	else:
		return False

class index:
	def GET(self):
		milage = db.select('milage', order='date(filleddate)')
		return render.index(milage, calcLPerKM, calcMPG)

class add:
	def POST(self):
		i = web.input()
		if i.kilometers == '' or i.fuel == '' or i.cost == '' or i.date == '':
			web.header('Content-Type', 'text/html')
			return '<a href="/gasmilage/index.py/"><h1>Do not leave boxes blank</h1></a>'
		if not is_number(i.kilometers) or not is_number(i.fuel) or not is_number(i.cost):
			web.header('Content-Type', 'text/html')
			return '<a href="/gasmilage/index.py/"><h1>Input is not numeric</h1></a>'
		else:
			n = db.insert('milage', kilometers=i.kilometers, fuel=i.fuel, cost=i.cost, filleddate=i.date)
			raise web.seeother('/')

class change:
	def GET(self):
		milage = db.select('milage', order='date(filleddate)')
		return render.change(milage, calcLPerKM, calcMPG)
	def POST(self):
		i = web.input()
		if checkPass(i.password):
			if i.id.isdigit():
				db.delete('milage', where='id=$i.id', vars=locals())
				raise web.seeother('/change')
			else:
				web.header('Content-Type', 'text/html')
				return '<a href="/gasmilage/index.py/change"><h1>Row ID Needs to be an integer</h1></a>'
		else:
			web.header('Content-Type', 'text/html')
			return '<a href="/gasmilage/index.py/change"><h1>Password Is Incorrect</h1></a>'

application = web.application(urls, globals()).wsgifunc()
if __name__ == '__main__':
	app = web.application(urls, globals())
	app.run()